@@ -1,5 +1,5 @@
-#  tests for libpython-2.0-py37h03978a9_1 (this is a generated file);
-print('===== testing package: libpython-2.0-py37h03978a9_1 =====');
+#  tests for libpython-2.1-py37h03978a9_0 (this is a generated file);
+print('===== testing package: libpython-2.1-py37h03978a9_0 =====');
 print('running run_test.py');
 #  --- run_test.py (begin) ---
 import sys
@@ -10,7 +10,9 @@ for kv in os.environ.items():
 
 print('CWD:', os.getcwd())
 print('sys.prefix:', sys.prefix)
-print('Pointer size:', tuple.__itemsize__)
+if hasattr(tuple, "__itemsize__"):
+    # This is a cpython implementation detail and not available in PyPy
+    print('Pointer size:', tuple.__itemsize__)
 
 from distutils.core import setup
 from distutils.extension import Extension
@@ -31,4 +33,4 @@ except:
     pass
 #  --- run_test.py (end) ---
 
-print('===== libpython-2.0-py37h03978a9_1 OK =====');
+print('===== libpython-2.1-py37h03978a9_0 OK =====');
